<!-- warning: Please don't edit this file. It was automatically generated. -->

# winui3-Microsoft.UI.Windowing

**IMPORTANT**: Packages in the `winui3-*` namespace cannot be used without the
Windows App Runtime. This has to be installed manually by the end user. Read the
[PyWinRT winui3 documentation](https://pywinrt.readthedocs.io/en/latest/api/winui3/index.html)
for more information.

Windows Runtime (WinRT) APIs for for the `winui3-Microsoft.UI.Windowing` namespace.

This package provides the `winui3.microsoft.ui.windowing` module.
